@@ -101,18 +101,18 @@ def add_random_synonymous_to_sentence(phrase, placeholder, synonyms):
     return phrase
 
 
-def data2nl(df, base_sentence=None):
+def data2nl(df, base_sentence=None, request=None, table_description=False):
     # The parameter "df" is a dataframe, but it will be converted into a dict, and called df in each case
 
+    if request is not None:
+        table_description = True
+    if base_sentence is not None:
+        table_description = False
+
     if not df.empty:
-
-        response_df = pd.DataFrame()
-
         headers = {
             "Content-Type": "application/json"
         }
-        dict_df = df.to_dict(orient='records')
-
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
@@ -120,13 +120,38 @@ def data2nl(df, base_sentence=None):
 
         url = url_list['BASE_URL_DATA2NL_DEV'] + "/data2nl"
 
-        for el in dict_df:
+        dict_df = df.to_dict(orient='records')
 
-            row = "Data: " + str(el)
+        if table_description is False:
+            response_df = pd.DataFrame()
 
-            if base_sentence is not None:
-                row = "BaseString: " + base_sentence + "\n" + row
+            for el in dict_df:
 
+                row = "Data: " + str(el)
+
+                if base_sentence is not None:
+                    row = "BaseString: " + base_sentence + "\n" + row
+
+                data = {"data": row}
+
+                r = s.post(url=url, headers=headers, json=data)
+                r.raise_for_status()
+
+                try:
+                    nl = r.json()['nl']
+                    el['nl'] = nl
+                except Exception as e:
+                    logging.error(str(e))
+                    el['generated_nl'] = ""
+                tmp_df = pd.DataFrame()
+                tmp_df = tmp_df.append(el, ignore_index=True)
+                response_df = pd.concat([response_df, tmp_df], ignore_index=True, axis=0)
+            return response_df
+        else:
+            row = "Table: " + str(dict_df)
+
+            if request is not None:
+                row = row + "\n" + "Request:\'" + request + "\'"
             data = {"data": row}
 
             r = s.post(url=url, headers=headers, json=data)
@@ -134,14 +159,11 @@ def data2nl(df, base_sentence=None):
 
             try:
                 nl = r.json()['nl']
-                el['nl'] = nl
             except Exception as e:
                 logging.error(str(e))
-                el['generated_nl'] = ""
-            tmp_df = pd.DataFrame()
-            tmp_df = tmp_df.append(el, ignore_index=True)
-            response_df = pd.concat([response_df, tmp_df], ignore_index=True, axis=0)
-        return response_df
+                nl = ""
+            return nl
+
     else:
         print("Input DataFrame is empty!")
         df_response = pd.DataFrame()
